public class Person {
    // Instance variables
    private String name;
    private int wake;
    private String music;
    private String personality;
    private boolean available;

    // Creates a Person with the given initial values. A Person is initially
    // available as a roommate.
    // Throws an IllegalArgumentException if the wakeTime is less than 4 or
    // greater than  12.
    public Person(String name, int wake, String music, String personality) {
        if (wake < 4 || wake > 12)
            throw new IllegalArgumentException("Wake time is invalid.");
        this.name = name;
        this.wake = wake;
        this.music = music;
        this.personality = personality;
        this.available = true;
    }

    // Returns a String representation of a Person of the form:
    // name wake music personality availability, e.g., Shawn 9 Jazz INTP true
    public String toString() {
        return name + " " + wake + " " + music + " " + personality + " " + available;
    }

    // Sets the Person’s roommate availability to true (available)
    // or false (unavailable)
    public void setStatus(boolean available) {
        this.available = available;
    }

    // Returns the Person’s roommate availability status
    public boolean isAvailable() {
        return available; // Replace with your solution
    }


    //  Returns true if the music Strings match
    public static boolean musicAffinity(String m1, String m2) {
        return m1.equals(m2) || m1.equals("All!") || m2.equals("All!");
    }

    // Return the number of characters in common in two personality strings.
    public static int personalityAffinity(String p1, String p2) {
        int count = 0;
        for (int i = 0; i < 4; i++) {
            if (p1.charAt(i) == p2.charAt(i))
                count++;
        }
        return count; // Replace with your solution
    }

    // Compute the overall affinity between this Person and the other Person
    public int affinity(Person other) {
        int musicAffinity = 0;
        if (musicAffinity(this.music, other.music))
            musicAffinity = 2;
        return 8 - Math.abs(this.wake - other.wake) + musicAffinity +
                personalityAffinity(this.personality, other.personality);
    }

    // Tests all instance methods in this class
    public static void main(String args[]) {
        Person p1 = new Person("Angel", 5, "All!", "INTP");
        Person p2 = new Person("Casey", 5, "Funk", "ESTJ");
        StdOut.println(p1);
        StdOut.println(p2);
        StdOut.println(p1.affinity(p1));
        StdOut.println(p1.affinity(p2));
        Person p3 = new Person("Invalid", 3, "Jazz", "ENFP");
    }
}
